summaryrefslogtreecommitdiffstats
path: root/rust/src/endpoints.rs
diff options
context:
space:
mode:
Diffstat (limited to 'rust/src/endpoints.rs')
-rw-r--r--rust/src/endpoints.rs8
1 files changed, 4 insertions, 4 deletions
diff --git a/rust/src/endpoints.rs b/rust/src/endpoints.rs
index a762fe18..2f30a7fa 100644
--- a/rust/src/endpoints.rs
+++ b/rust/src/endpoints.rs
@@ -17,9 +17,9 @@ use crate::identifiers::FatcatId;
use crate::server::*;
use cadence::prelude::*;
use diesel::Connection;
-use fatcat_api_spec::models;
-use fatcat_api_spec::models::*;
-use fatcat_api_spec::*;
+use fatcat_openapi::models;
+use fatcat_openapi::models::*;
+use fatcat_openapi::*;
use futures::{self, Future};
use sentry::integrations::failure::capture_fail;
use std::cmp;
@@ -62,7 +62,7 @@ macro_rules! generic_err_responses {
}
/// Helper for generating wrappers (which return "Box::new(futures::done(Ok(BLAH)))" like the
/// codegen fatcat-api-spec code wants) that call through to actual helpers (which have simple
/// Result<> return types)
macro_rules! wrap_entity_handlers {
// Would much rather just have entity ident, then generate the other fields from that, but Rust
@@ -62,7 +62,7 @@ macro_rules! generic_err_responses {
}
/// Helper for generating wrappers (which return "Box::new(futures::done(Ok(BLAH)))" like the
-/// codegen fatcat-api-spec code wants) that call through to actual helpers (which have simple
+/// codegen fatcat-openapi code wants) that call through to actual helpers (which have simple
/// Result<> return types)
macro_rules! wrap_entity_handlers {